pacman-game
===============================

version number: 1.0.2.dev1
author: Parth Kolekar
[![Build Status](https://travis-ci.org/ParthKolekar/pacman-game.svg?branch=master)](https://travis-ci.org/ParthKolekar/pacman)
[![Coverage Status](https://coveralls.io/repos/ParthKolekar/pacman-game/badge.svg)](https://coveralls.io/r/ParthKolekar/pacman)
[![PyPI version](https://badge.fury.io/py/pacman-game.svg)](https://pypi.python.org/pypi/pacman-game/)

Overview
--------

A Pacman Like Game with new and interesting new features.

Installation / Usage
--------------------

To install use pip:

    $ pip install pacman-game


Or clone the repo:

    $ git clone https://github.com/ParthKolekar/pacman-game.git
    $ python setup.py install
    
